@@ -11,9 +11,6 @@
 #' # Find the concepts
 #' fc_planets$find_concepts()
 #'
-#' # Plot the concept lattice
-#' fc_planets$concepts$plot()
-#'
 #' # Find join- and meet- irreducible elements
 #' fc_planets$concepts$join_irreducibles()
 #' fc_planets$concepts$meet_irreducibles()
@@ -22,6 +19,8 @@
 #' fc_planets$concepts$support()
 #'
 #' @export
+#' @import R6
+#'
 ConceptLattice <- R6::R6Class(
 
   classname = "ConceptLattice",
@@ -161,157 +160,28 @@ ConceptLattice <- R6::R6Class(
 
       }
 
-      if (to_latex) {
+      if (!requireNamespace("hasseDiagram", quietly = TRUE)) {
 
-        if (object_names) {
+        warning("You have not installed the 'hasseDiagram' package, which is needed to plot the lattice.",
+                call. = FALSE)
 
-          labels <- sapply(private$concepts,
-                           function(l) l$to_latex(print = FALSE)) %>%
-            stringr::str_replace_all(pattern = "\n",
-                                     replacement = "")
-
-        } else {
-
-          labels <- sapply(private$concepts,
-                           function(l) {
-                             v <- l$get_intent()
-                             v$to_latex(print = FALSE)
-                           })
-
-        }
-
-        labels <- labels %>%
-          stringr::str_replace_all(pattern = stringr::fixed(" "),
-                                   replacement = "\\,")
-
-      } else {
-
-        if (object_names) {
-
-          labels <- sapply(private$concepts,
-                           function(l) .concept_to_string(l,
-                                                          private$objects,
-                                                          private$attributes))
-
-        } else {
-
-          labels <- sapply(private$concepts,
-                           function(l) {
-                             v <- l$get_intent()
-                             .set_to_string(S = v$get_vector(),
-                                            attributes = v$get_attributes())
-                           })
-
-        }
+        return(invisible(FALSE))
 
       }
 
-
       if ((self$size() > 0) & (is.null(private$subconcept_matrix))) {
 
         private$subconcept_matrix <- .subset(private$pr_extents)
 
       }
 
-      if (to_latex) {
+      lattice_plot(private$concepts,
+                   private$subconcept_matrix,
+                   private$objects,
+                   private$attributes,
+                   object_names,
+                   to_latex, ...)
 
-        tmp_file <- tempfile(fileext = ".tex")
-        dots <- list(...)
-        args <- list(file = tmp_file,
-                     standAlone = FALSE,
-                     sanitize = FALSE,
-                     width = 6,
-                     height = 4)
-
-        if ("filename" %in% names(dots)) {
-
-          filename <- dots$filename
-          dots$filename <- NULL
-
-        } else {
-
-          filename <- tempfile(fileext = ".tex")
-
-        }
-
-        if ("caption" %in% names(dots)) {
-
-          caption <- dots$caption
-          dots["caption"] <- NULL
-          label <- dots$label
-          if (is.null(label)) {
-
-            label <- "fig:"
-
-          } else {
-
-            dots["label"] <- NULL
-
-          }
-
-          caption <- paste0("\\label{",
-                            label,
-                            "}",
-                            caption)
-
-          tex_prefix <- c("\\begin{figure}",
-                          "\\centering",
-                          "")
-
-          tex_suffix <- c("",
-                          paste0("\\caption{", caption, "}"),
-                          "",
-                          "\\end{figure}")
-
-        } else {
-
-          tex_prefix <- c()
-          tex_suffix <- c()
-
-        }
-
-        old_opt <- getOption("tikzDocumentDeclaration")
-
-        if ("pointsize" %in% names(dots)) {
-
-          options("tikzDocumentDeclaration" = paste0("\\documentclass[", dots$pointsize,
-                                                     "pt]{article}\n"))
-
-        }
-
-        options( tikzLatexPackages = c(
-          getOption( "tikzLatexPackages" ),
-          "\\usepackage{amssymb}"
-        ))
-
-        args[names(dots)] <- dots[names(dots)]
-
-        do.call(tikzDevice::tikz, args = args)
-
-      }
-
-      hasseDiagram::hasse(data = Matrix::as.matrix(Matrix::t(private$subconcept_matrix)),
-                          labels = labels,
-                          parameters = list(arrows = "backward"))
-
-      if (to_latex) {
-
-        dev.off()
-
-        tex <- readLines(tmp_file)
-        unlink(tmp_file)
-
-        tex <- c(tex_prefix,
-                 tex,
-                 tex_suffix)
-
-        options("tikzDocumentDeclaration" = old_opt)
-        my_tex <- paste0(tex, collapse = "\n")
-        cat(my_tex, file = filename)
-
-        return(filename)
-
-      }
 
     },
 
