@@ -4,13 +4,18 @@
 
   for (i in seq(n)) {
 
-    A <- Matrix(LHS[, 1], sparse = TRUE)
-    B <- Matrix(RHS[, 1], sparse = TRUE)
-    LHS <- Matrix(LHS[, -1], sparse = TRUE)
-    RHS <- Matrix(RHS[, -1], sparse = TRUE)
+    A <- Matrix::Matrix(LHS[, 1], sparse = TRUE)
+
+    B <- Matrix::Matrix(RHS[, 1], sparse = TRUE)
+
+    LHS <- Matrix::Matrix(LHS[, -1], sparse = TRUE)
+    RHS <- Matrix::Matrix(RHS[, -1], sparse = TRUE)
+
     AUB <- .union(A, B)
+
     B <- .compute_closure(AUB, LHS, RHS,
                           attributes, reduce = FALSE)$closure
+
     LHS <- cbind(LHS, A)
     RHS <- cbind(RHS, B)
 
@@ -18,10 +23,13 @@
 
   for (i in seq(n)) {
 
-    A <- Matrix(LHS[, 1], sparse = TRUE)
-    B <- Matrix(RHS[, 1], sparse = TRUE)
-    LHS <- Matrix(LHS[, -1], sparse = TRUE)
-    RHS <- Matrix(RHS[, -1], sparse = TRUE)
+    A <- Matrix::Matrix(LHS[, 1], sparse = TRUE)
+
+    B <- Matrix::Matrix(RHS[, 1], sparse = TRUE)
+
+    LHS <- Matrix::Matrix(LHS[, -1], sparse = TRUE)
+    RHS <- Matrix::Matrix(RHS[, -1], sparse = TRUE)
+
     A <- .compute_closure(A, LHS, RHS,
                           attributes, reduce = FALSE)$closure
 
@@ -34,6 +42,6 @@
 
   }
 
-  return(list(lhs = LHS, rhs = RHS))
+  return(list(lhs = LHS, rhs = .difference2(RHS, LHS)))
 
 }
